@@ -20,7 +20,7 @@ def is_python(major: int, minor: int) -> bool:
 
 _ABSEIL_REQ = "abseil-cpp==20220623.*"
 _BENCHMARK_REQ = "benchmark>=1.7,<1.8"
-_CMAKE_REQ = "cmake>=3.18"
+_CMAKE_REQ = "cmake>=3.21"
 _NUMPY_REQ = "numpy>=1.23,<1.25"
 _TBB_VER = "==2021.6.*"
 _TBB_REQ = "tbb" + _TBB_VER
@@ -124,7 +124,7 @@ flake8_reqs = [
 
 # Clang-format formatting requirements.
 clang_format_reqs = [
-    "clang-format",
+    "clang-format>=15",
 ]
 
 # Complete developer requirements.
